#!/bin/bash

#This routine performs clustering on a set of trajectories using the PAMM algorithm (https://github.com/lab-cosmo/pamm)
#according to the values of a CV computed by plumed. The structure is the following: 

# 1) provide a file Temps-all.dat with a list of simulated temperatures (corresponding to one cell size: 6x6x6, or 8x8x8, etc.); this assumes that the trajectories corresponding to one size and different temperatures are output in separate folders, named as $TEMP'K'; 

# 2) we access each folder individually and print out two quantities in two separate files: NPmodB collects the number of steps of each trajectory, while PmodB collects the time series of the CV computed in plumed (the polarization modulus in case we are interested about the ferroelectric-paraelectric phase transition of BTO); this is needed because we cluster PmodB after having collected the data of all trajectories and hence we need NPmodB to keep track of which sections of the final output by pamm correspond to which trajectory;

# 3) we use the pamm algorithm to cluster the data - please adjust the parameters -ngrid and -qs in such a way that the number of generated clusters is correct (in our case we want to have two clusters corresponding to tetragonal and cubic states). In general, qs is related to the expected radius of the clusters and ngrid the resolution of the grid in CV space (please refer to Gasparotto et al., J. Chem. Theory Comput. 2018, 14, 2, 486–498 Secs. 2.1, 2.2, 2.3 for detailed information). The option -d corresponds to the dimension of the input data - 1d in case we only use the polarization modulus.

# 4) pamm generates three outputs: clusters.pamm provides a summary of the clusters that were found - number of clusters detected (make sure this is what you want), centroid of each cluster in CV space and percentage of points that fall within each cluster; Clusters.dat is the most important output because it contains the series of values of the CV (1st column) and the LOG of the probabilities that each point belongs to each cluster. The EXP of these quantities can be used, together with the weights computed by ITRE, to compute the relative free energies of the two competing phases. The last column of Clusters.dat just recalls the number of clusters detected. 

TEMPS=$(cat Temps-all.dat)
for T in $TEMPS; do
	cd $T'K/';
	awk '{if($1 != "#!") print $7;}' PVARS | wc -l >> ../NPmodB;
	awk '{if($1 != "#!") print $7;}' PVARS >> ../PmodB;
	cd ../;
done

../pamm/bin/pamm -d 1 -o clusters -ngrid 1000 -qs 2.0 < PmodB;
../pamm/bin/pamm -d 1 -gf clusters.pamm < PmodB > Clusters.dat;
echo $T;
cat clusters.pamm;

