import ase
import pymatgen
from pymatgen.io.cif import CifParser
from pymatgen.io.ase import AseAtomsAdaptor
from ase.io import read, write
from ase import Atoms
import numpy as np

print("What supercell do you want to simulate?")
ax = input("ax = ")
ay = input("ay = ")
az = input("az = ")
parser = CifParser("BTO.cif")
structure = parser.get_structures()[0]
structure.make_supercell([ax, ay, az])
Asereader = AseAtomsAdaptor()
ase_struct = Asereader.get_atoms(structure)
pos_Ba = ase_struct.get_positions()[np.where(ase_struct.symbols == "Ba")]
pos_Ti = ase_struct.get_positions()[np.where(ase_struct.symbols == "Ti")]
pos_O = ase_struct.get_positions()[np.where(ase_struct.symbols == "O")]

pos_tmp = np.vstack([pos_Ba, pos_Ti])
pos = np.vstack([pos_tmp, pos_O])
nBa = int(ax)*int(ay)*int(az)
nTi = int(ax)*int(ay)*int(az)
nO = 3*int(ax)*int(ay)*int(az)
ase_struct_new = Atoms("Ba{}Ti{}O{}".format(nBa, nTi, nO), positions=pos, cell=ase_struct.get_cell(), pbc=True)

write("BaTiO3_cubic_{}x{}x{}.input".format(ax, ay, az), ase_struct_new, format='lammps-data', specorder=['Ba','Ti','O'])
write("BaTiO3_cubic_{}x{}x{}.xyz".format(ax, ay, az), ase_struct_new, format='extxyz')

#To make the lammps input structure work in i-PI when running NST simulations, please add the following line just below the cell parameters (in the *.input file they correspond to the lines containing xlo xhi, ylo yhi, zlo zhi):

#1.0e-08 1.0e-08 1.0e-08 xy xz yz

#In other words, a small but non-zero tilt is needed to correctly initialize the barostat in i-PI.

#Please also modify the header line of the xyz file from ASE to i-PI format, i.e. from

#           Lattice="..." Properties=species:S:1:pos:R:3 pbc="T T T"  
# to
#           #CELL{H}= ... cell{angstrom} positions{angstrom}

