#This script reweigths a metadynamics trajectory with ITRE - please download the cosmo-tools from
#https://github.com/lab-cosmo/cosmo-tools 
#and set cosmo-tools/python/ITRE in your PYTHONPATH

import numpy as np
import itre

hills = np.loadtxt("HILLS")

#This zeroes the wall, please modify if the metadynamics has walls
wall = np.zeros(len(hills)) 

#This reads the temperature from the i-pi output, please modify if necessary
temp=np.loadtxt("BaTiO3_MD.out")[0,9]

#kB expressed in kJ/(mol*K)
kB = 0.0083144626

#Load all the relevant data from HILLS file -  please check that the columns of hills represent the
#time series of the following quantities:

#hills[:,1] = collective variable 
#hills[:,2] = gaussian sigma 
#hills[:,3] = gaussian hills
#hills[:,4] = bias factor

#Please modify this script if you have multiple collective variables.

run_ct =itre.Itre()
run_ct.use_numba=True
run_ct.kT=kB*temp
run_ct.colvars = hills[:,1]
run_ct.sigmas = hills[:,2]
run_ct.heights = hills[:,3]*(1-1/hills[:,4])
run_ct.stride = 1
run_ct.wall = wall
run_ct.n_evals=int(len(hills)/run_ct.stride)
run_ct.calculate_c_t()

#Save c_t, the instantaneous bias and the final weights computed by ITRE
np.savetxt('c_t.dat', run_ct.ct[-1].T, header="# c_t")
np.savetxt('instantaneous_bias.dat',run_ct.instantaneous_bias, header="# instantaneous_bias")
h = (run_ct.instantaneous_bias-run_ct.ct[-1].T)/run_ct.kT
h -= h.mean()
w = np.exp(h)/np.exp(h).mean()
np.savetxt('weights.dat', w, header="# weights")
